Internal API DTOs for scheduler-to-agent communication.
These types describe the request/response payloads for the internal endpoints used by the distributed scheduler to trigger operations on agents. They use a shared secret for authentication rather than JWT tokens.
Re-exports
pub use crate::cluster::InternalScaleRequest;pub use crate::cluster::ScaleAssignment;
Structs
- Internal
AddPeer Request - Request to add a
WireGuardpeer to the local overlay transport. - Internal
AddPeer Response - Response from internal add-peer operation
- Internal
Scale Response - Response from internal scale operation
Enums
- Secrets
Raft Op - Op type for the secrets Raft state machine.