pub struct SystemPruneReport {
pub stopped_containers: Vec<String>,
pub dead_deployments: Vec<String>,
pub deleted_images: Vec<String>,
pub deleted_volumes: Vec<String>,
pub deleted_networks: Vec<String>,
pub reclaimed_layers: Vec<String>,
pub reclaimed_blobs: Vec<String>,
pub reclaimed_bundles: Vec<String>,
pub space_reclaimed_bytes: u64,
}Expand description
Summary of what zlayer system prune removed, per category + totals.
Fields
stopped_containers: Vec<String>Per-category removed-item identifiers (container ids, image refs, volume names, layer digests, deployment names, …).
dead_deployments: Vec<String>deleted_images: Vec<String>deleted_volumes: Vec<String>deleted_networks: Vec<String>reclaimed_layers: Vec<String>reclaimed_blobs: Vec<String>reclaimed_bundles: Vec<String>space_reclaimed_bytes: u64Total bytes reclaimed across all categories.
Implementations
Sourceimpl SystemPruneReport
impl SystemPruneReport
Sourcepub fn total_items(&self) -> usize
pub fn total_items(&self) -> usize
Total number of removed items across all categories.