pub struct ContainerSummary {
pub id: String,
pub service: String,
pub replica: u32,
pub image: String,
pub state: String,
pub pid: Option<u32>,
pub overlay_ip: Option<String>,
pub node_id: Option<String>,
}Expand description
Container summary for API responses
Fields
id: StringContainer identifier (service-rep-N)
service: StringService name
replica: u32Replica number
image: StringImage reference the container was created from (canonical form, e.g.
docker.io/library/nginx:1.29-alpine).
#[serde(default)] keeps older payloads (which lacked this field)
deserializable.
state: StringContainer state
pid: Option<u32>Process ID (if running)
overlay_ip: Option<String>Overlay IP (if assigned)
node_id: Option<String>Raft node ID of the daemon that owns this container (if known).
Each daemon tags containers it knows about with its own local node ID.
None when the API is running in read-only mode (no local Raft node).